<?php
// $Id: weblinks.admin.inc,v 1.26 2008/07/23 01:53:13 rmiddle Exp $

/**
 * @file
 * Settings form.
 */

/**
 * Module settings page.
 */
function weblinks_settings_page() {
  return drupal_get_form('weblinks_admin_settings');
}
 
function weblinks_admin_settings() {
  drupal_add_js(drupal_get_path('module', 'weblinks') .'/weblinks.js');

/**
 * Overall settings.
 */
  $vocabs = taxonomy_get_vocabularies('weblinks');
  if (count($vocabs) > 1) {
    $avail_vocs = array();
    foreach ($vocabs as $vid => $vocabulary) {
      $avail_vocs[$vid] = check_plain($vocabulary->name);
    }
    ksort($avail_vocs);
    $form['weblinks_nav_vocabulary'] = array(
      '#type' => 'radios',
      '#title' => t('Vocabulary to use for Weblinks'),
      '#default_value' => variable_get('weblinks_nav_vocabulary', ''),
      '#options' => $avail_vocs,
      '#required' => TRUE,
      '#prefix' => '<div class="weblinks-radios">',
      '#suffix' => '</div><div class="clear-block"></div>',
      );
  }
  else {
    if (count($vocabs) < 1) {
      variable_del('weblinks_nav_vocabulary');
      _weblinks_get_vocid();
      drupal_set_message(t('No vocabulary for the weblinks content type was found. A new vocabulary was created.'));
    }
  }

  $form['weblinks_allow_dupes'] = array(
    '#type' => 'radios',
    '#title' => t('Allow duplicate URLs'),
    '#default_value' => variable_get('weblinks_allow_dupes', 0),
    '#options' => array('yes', 0 => 'no'),
    '#description' => t('Most users will not want to allow duplicate URLs.'),
    '#prefix' => '<div class="weblinks-radios">',
    '#suffix' => '</div><div class="clear-block"></div>',
    );

  $form['page'] = array(
    '#type' => 'fieldset',
    '#title' => t('Links page settings'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
    );

/**
 * Settings for the links page.
 */
  $form['page']['weblinks_collapsible'] = array(
    '#type' => 'checkbox',
    '#title' => t('Make categories collapsible'),
    '#default_value' => variable_get('weblinks_collapsible', FALSE),
    '#description' => t('Enable this if you want the categories to be collapsible on the main page.'),
    '#required' => FALSE,
    );

  $sort_options = array(
    'standard' => 'Normal Drupal - by weight, sticky, created date.',
    'title' => 'Legacy - by weight and title.',
    );
  $form['page']['weblinks_page_sort'] = array(
    '#type' => 'radios',
    '#options' => $sort_options,
    '#title' => t('Page Sort order'),
    '#default_value' => variable_get('weblinks_page_sort', 'title'),
    '#description' => t('This determines how the links page will sort the links.'),
    '#required' => FALSE,
    '#prefix' => '<div class="weblinks-radios">',
    '#suffix' => '</div><div class="clear-block"></div>',
    );

  $form['page']['weblinks_pagedesc'] = array(
    '#type' => 'textarea',
    '#title' => t('Page information'),
    '#rows' => 5,
    '#default_value' => variable_get('weblinks_pagedesc', NULL),
    '#description' => t('This description will appear at the top of the links page.  It will be filtered by your default input format.'),
    '#required' => FALSE,
    );

  // Disallow blank setting.
  $mfd_default = variable_get('weblinks_maxfrontdepth', 1);
  if (!is_numeric($mfd_default)) {
    $mfd_default = 1;
  }
  $form['page']['weblinks_maxfrontdepth'] = array(
    '#type' => 'textfield',
    '#title' => t('Maximum group depth (front page)'),
    '#default_value' => $mfd_default,
    '#description' => t('This controls how many subcategories, if any, will display on the main links page. Blank, zero (0), and one (1) will all show only the top level.'),
    '#required' => FALSE,
    '#size' => 2,
    );

  $form['page']['weblinks_unclassified_title'] = array(
    '#type' => 'textfield',
    '#title' => t('Title for unclassified links'),
    '#default_value' => variable_get('weblinks_unclassified_title', t('Unclassified')),
    '#description' => t('This will be used to describe the unclassified links. You may leave it blank for no title.'),
    '#required' => FALSE,
    );

/**
 * Settings for group display.
 */
  $form['group'] = array(
    '#type' => 'fieldset',
    '#title' => t('Group settings'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
    );

  $form['group']['weblinks_catdesc'] = array(
    '#type' => 'checkbox',
    '#title' => t('Display group descriptions'),
    '#default_value' => variable_get('weblinks_catdesc', TRUE),
    '#description' => t('Generally recommended.'),
    '#required' => FALSE,
    );

  $form['group']['weblinks_empty_text'] = array(
    '#type' => 'textarea',
    '#title' => t('Empty container text'),
    '#rows' => 2,
    '#default_value' => variable_get('weblinks_empty_text', NULL),
    '#description' => t('This text will appear when a container is empty. Leave it blank to not show the group at all. It will be filtered by your default input format.'),
    '#required' => FALSE,
    );

/**
 * Settings for link display.
 */
  $form['link'] = array(
    '#type' => 'fieldset',
    '#title' => t('Link settings'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
    );

  $form['link']['weblinks_urlnode'] = array(
    '#type' => 'radios',
    '#title' => t('Links lead URL or to Web Link node'),
    '#default_value' => variable_get('weblinks_urlnode', 'url'),
    '#description' => t('Most people will want to leave this as URL. Specifying "node" makes it easier to edit the links, but requires an additional click to follow the link.'),
    '#options' => array('url' => 'URL', 'node' => 'node'),
    '#prefix' => '<div class="weblinks-radios">',
    '#suffix' => '</div><div class="clear-block"></div>',
    );

  $form['link']['weblinks_external'] = array(
    '#type' => 'radios',
    '#title' => t('Open links in a new window'),
    '#default_value' => variable_get('weblinks_external', TRUE),
    '#options' => array(1 => 'yes', 0 => 'no'),
    '#description' => t('Recommended to keep your vistors on your site. Should not be used when the "Links lead..." option is "node."'),
    '#prefix' => '<div class="weblinks-radios">',
    '#suffix' => '</div><div class="clear-block"></div>',
    );

  $form['link']['weblinks_linkdesc'] = array(
    '#type' => 'checkbox',
    '#title' => t('Display individual link descriptions'),
    '#default_value' => variable_get('weblinks_linkdesc', TRUE),
    '#description' => t('Generally recommended.'),
    );

  $form['link']['weblinks_linkinfo'] = array(
    '#type' => 'checkbox',
    '#title' => t('Display link information'),
    '#default_value' => variable_get('weblinks_linkinfo', TRUE),
    '#description' => t('This displays link author, publish date, and revision date'),
    );

  $form['link']['weblinks_comment_links'] = array(
    '#type' => 'checkbox',
    '#title' => t('Display comment information'),
    '#default_value' => variable_get('weblinks_comment_links', FALSE),
    '#description' => t('Shows links for adding and viewing comments.'),
    );

  $form['link']['weblinks_nofollow'] = array(
    '#type' => 'checkbox',
    '#title' => t('Spam link deterrent'),
    '#default_value' => variable_get('weblinks_nofollow', FALSE),
    '#description' => t('If enabled, Drupal will add rel="nofollow" to all links, as a measure to reduce the effectiveness of spam links. Note: this will also prevent valid links from being followed by search engines, therefore it is likely most effective when enabled for anonymous users.'),
    );

  $form['link']['weblinks_view_position'] = array(
    '#type' => 'radios',
    '#title' => t('Link position on view'),
    '#options' => array(-1 => 'above', 1 => 'below'),
    '#default_value' => variable_get('weblinks_view_position', -1),
    '#description' => t('This option sets whether the link itself will be displayed above or below the description when viewing the node.'),
    '#prefix' => '<div class="weblinks-radios">',
    '#suffix' => '</div>',
    );

  return system_settings_form($form);
}

function weblinks_group_settings($form_state) {
  $tree = taxonomy_get_tree(_weblinks_get_vocid());
  $rows = $form = array();
  $form = array('#tree' => TRUE);

  foreach ($tree as $term) {
    $form[$term->tid]['tid'] = array(      
      '#type' => 'value',
      '#value' => $term->tid,
      );

    $form[$term->tid]['enable'] = array(      
      '#type' => 'checkbox',
      '#title' => str_repeat('&emsp;&emsp;', $term->depth) . t('Show !name', array('!name' => check_plain($term->name))),
      '#default_value' => variable_get('weblinks_page_'. $term->tid, TRUE),
      '#description' => t('Check to display this group on the main page.'),
      );

    // Set the maximum number of links to display for each group
    $form[$term->tid]['maxdisp'] = array(
      '#type' => 'textfield',
      '#title' => t('Maximum links to display'),
      '#size' => 2,
      '#default_value' => variable_get('weblinks_maxdisp_'. $term->tid, ''),
      '#description' => t('Leave blank if you would not like to limit the number of links displayed'),
      );
  }

  $form['submit'] = array('#type' => 'submit', '#value' => 'Save');
  return $form;
}

function theme_weblinks_group_settings($form) {
  $rows = array();
  foreach (element_children($form) as $key) {
    if (isset($form[$key]['tid'])) {
      $tid = $form[$key]['tid']['#value'];

      $row = array();
      $row[] = drupal_render($form[$key]['enable']);
      $row[] = drupal_render($form[$key]['maxdisp']);
      $rows[] = array('data' => $row, 'class' => 'weblinks-group', 'valign' => 'top');
    }
  }
  if (empty($rows)) {
    $rows[] = array(array('data' => t('No groups available.'), 'colspan' => '5'));
  }

  return theme('table', array(), $rows, array('id' => 'weblinks-groups')) . drupal_render($form);
}

function weblinks_group_settings_submit($form, &$form_state) {
  foreach ($form_state['values'] as $row => $values) {
    if (is_array($values) && array_key_exists('tid', $values)) {
      variable_set('weblinks_page_'. $values['tid'], $values['enable']);
      variable_set('weblinks_maxdisp_'. $values['tid'], $values['maxdisp']);
    }
  }
}
